@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2015-09-06'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-09-08'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -176,7 +176,7 @@ sub _read_string {
 }
 
 1;
-# ABSTRACT: Read IOD configuration files
+# ABSTRACT: Read IOD/INI configuration files
 
 __END__
 
@@ -186,11 +186,11 @@ __END__
 
 =head1 NAME
 
-Config::IOD::Reader - Read IOD configuration files
+Config::IOD::Reader - Read IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.18 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-09-06.
+This document describes version 0.19 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-09-08.
 
 =head1 SYNOPSIS
 
@@ -213,9 +213,11 @@ This document describes version 0.18 of Config::IOD::Reader (from Perl distribut
 
 =head1 DESCRIPTION
 
-This module reads L<IOD> configuration files. It is a minimalist alternative to
-the more fully-featured L<Config::IOD>. It cannot write IOD files and is
-optimized for low startup overhead.
+This module reads L<IOD> configuration files (IOD is an INI-like format with
+more precise specification, some extra features, and 99% compatible with typical
+INI format). It is a minimalist alternative to the more fully-featured
+L<Config::IOD>. It cannot write IOD files and is optimized for low startup
+overhead.
 
 =head1 EXPRESSION
 
@@ -412,7 +414,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Config-IOD-Reader>.
+Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
 
 =head1 BUGS
 
